==> nextcloud-30.0.5.tgz: nextcloud/apps/files_reminders/l10n/ug.js <==
OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "ھۆججەت ئەسكەرتىشلىرى",
    "Reminder for {name}" : "{name} for ئەسكەرتىش",
    "View file" : "ھۆججەتنى كۆرۈش",
    "View folder" : "ھۆججەت قىسقۇچنى كۆرۈش",
    "Set file reminders" : "ھۆججەت ئەسكەرتىشلىرىنى بەلگىلەڭ",
    "We will remind you of this file" : "بۇ ھۆججەتنى ئەسكەرتىمىز",
    "Please choose a valid date & time" : "ئىناۋەتلىك چېسلا ۋە ۋاقىتنى تاللاڭ",
    "Cancel" : "بىكار قىلىش",
    "Clear reminder" : "ئەسكەرتىش",
    "Set reminder" : "ئەسكەرتىش بەلگىلەڭ",
    "Set reminder for \"{fileName}\"" : "\"{fileName}\" ئۈچۈن ئەسكەرتىش بەلگىلەڭ",
    "Set reminder at custom date & time" : "ئىختىيارى چېسلا ۋە ۋاقىتتا ئەسكەرتىش بەلگىلەڭ",
    "Reminder set for \"{fileName}\"" : "\"{fileName}\" ئۈچۈن ئەسكەرتىش",
    "Failed to set reminder" : "ئەسكەرتىش بەلگىلەش مەغلۇب بولدى",
    "Reminder cleared for \"{fileName}\"" : "ئەسكەرتىش \"{fileName}\" ئۈچۈن تازىلاندى",
    "Failed to clear reminder" : "ئەسكەرتىشنى تازىلاش مەغلۇب بولدى",
    "Reminder set" : "ئەسكەرتىش",
    "Set custom reminder" : "ئىختىيارى ئەسكەرتىش بەلگىلەڭ",
    "Later today" : "بۈگۈن بۈگۈن",
    "Set reminder for later today" : "بۈگۈنگە ئەسكەرتىش بەلگىلەڭ",
    "Tomorrow" : "ئەتە",
    "Set reminder for tomorrow" : "ئەتە ئۈچۈن ئەسكەرتىش بەلگىلەڭ",
    "This weekend" : "بۇ ھەپتە ئاخىرى",
    "Set reminder for this weekend" : "بۇ ھەپتە ئاخىرىدا ئەسكەرتىش بەلگىلەڭ",
    "Next week" : "كېلەر ھەپتە",
    "Set reminder for next week" : "كېلەر ھەپتە ئەسكەرتىش بەلگىلەڭ"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-31.0.9.tgz: nextcloud/apps/files_reminders/l10n/ug.js <==
OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "ھۆججەت ئەسكەرتىشلىرى",
    "Reminder for {name}" : "{name} for ئەسكەرتىش",
    "View file" : "ھۆججەتنى كۆرۈش",
    "View folder" : "ھۆججەت قىسقۇچنى كۆرۈش",
    "Set file reminders" : "ھۆججەت ئەسكەرتىشلىرىنى بەلگىلەڭ",
    "Set reminder for \"{fileName}\"" : "\"{fileName}\" ئۈچۈن ئەسكەرتىش بەلگىلەڭ",
    "Clear reminder" : "ئەسكەرتىش",
    "Please choose a valid date & time" : "ئىناۋەتلىك چېسلا ۋە ۋاقىتنى تاللاڭ",
    "Reminder set for \"{fileName}\"" : "\"{fileName}\" ئۈچۈن ئەسكەرتىش",
    "Failed to set reminder" : "ئەسكەرتىش بەلگىلەش مەغلۇب بولدى",
    "Reminder cleared for \"{fileName}\"" : "ئەسكەرتىش \"{fileName}\" ئۈچۈن تازىلاندى",
    "Failed to clear reminder" : "ئەسكەرتىشنى تازىلاش مەغلۇب بولدى",
    "We will remind you of this file" : "بۇ ھۆججەتنى ئەسكەرتىمىز",
    "Cancel" : "بىكار قىلىش",
    "Set reminder" : "ئەسكەرتىش بەلگىلەڭ",
    "Reminder set" : "ئەسكەرتىش",
    "Later today" : "بۈگۈن بۈگۈن",
    "Set reminder for later today" : "بۈگۈنگە ئەسكەرتىش بەلگىلەڭ",
    "Tomorrow" : "ئەتە",
    "Set reminder for tomorrow" : "ئەتە ئۈچۈن ئەسكەرتىش بەلگىلەڭ",
    "This weekend" : "بۇ ھەپتە ئاخىرى",
    "Set reminder for this weekend" : "بۇ ھەپتە ئاخىرىدا ئەسكەرتىش بەلگىلەڭ",
    "Next week" : "كېلەر ھەپتە",
    "Set reminder for next week" : "كېلەر ھەپتە ئەسكەرتىش بەلگىلەڭ",
    "Set reminder at custom date & time" : "ئىختىيارى چېسلا ۋە ۋاقىتتا ئەسكەرتىش بەلگىلەڭ",
    "Set custom reminder" : "ئىختىيارى ئەسكەرتىش بەلگىلەڭ"
},
"nplurals=2; plural=(n != 1);");
